Package 'epp'

Title: R Implementation of the EPP model for HIV epidemic estimates.
Description: This implements the EPP r-spline and r-trend models for HIV epidemic estimates.
Authors: Jeff Eaton [aut, cre]
Maintainer: Jeff Eaton <[email protected]>
License: GPL-3
Version: 0.4.4
Built: 2026-06-02 09:16:06 UTC
Source: https://github.com/jeffeaton/epp

Help Index


Parse java array from EPP .xml file

Description

Parse java array from EPP .xml file

Usage

.parse_array(x)

Arguments

x

‘xml_node' object with tag ’array'


Parse java matrix from EPP .xml file

Description

Parse java matrix from EPP .xml file

Usage

.parse_matrix(x)

Arguments

x

‘xml_node' object with tag ’array' and type '[D' or '[I'


Return workset with names from EPP .xml file

Description

Return workset with names from EPP .xml file

Usage

get_eppxml_workset(pjnz)

Arguments

x

‘xml_node' object with tag ’array'


Prepare site-level ANC prevalence data for EPP random-effects likelihood

Description

Prepare site-level ANC prevalence data for EPP random-effects likelihood

Usage

prepare_ancsite_likdat(eppd, anchor.year = 1970L)

Arguments

eppd

EPP data object

anchor.year

year in which EPP data inputs start NOTE: requires year to be stored in column names of anc.prev


Read EPP fitting surveillance data

Description

Reads the HIV prevalence from sentinel surveillance and household surveillance data from the EPP .xml file within a PJNZ.

Usage

read_epp_data(pjnz)

Arguments

pjnz

file path to Spectrum PJNZ file.

Details

EPP projection sets are identified in the .xml file by searching the XML tree for tag "object", and then selecting objects with "class" attribute equal to "epp2011.core.sets.ProjectionSet".


Read EPP subpopulation configuration

Description

Reads the subpopulation configuration and population sizes from the EPP .xml file within a PJNZ.

Usage

read_epp_subpops(pjnz)

Arguments

pjnz

file path to Spectrum PJNZ file.

Details

EPP projection sets are identified in the .xml file by searching the XML tree for tag "object", and then selecting objects with "class" attribute equal to "epp2011.core.sets.ProjectionSet".


Read EPP Workset Options

Description

Parse 'Worset option' selections for overall EPP workset in the "Model options" pop up box in the Curve Fitting workflow

Usage

read_epp_workset_options(pjnz)

Arguments

pjnz

file path to Spectrum PJNZ file


Read Bayesian Median outputs from XML

Description

Read Bayesian Median outputs from XML

Usage

read_eppxml_results(pjnz)

Arguments

pjnz