| Title: | R Implementation of the EPP model for HIV epidemic estimates. |
|---|---|
| Description: | This implements the EPP r-spline and r-trend models for HIV epidemic estimates. |
| Authors: | Jeff Eaton [aut, cre] |
| Maintainer: | Jeff Eaton <[email protected]> |
| License: | GPL-3 |
| Version: | 0.4.4 |
| Built: | 2026-06-02 09:16:06 UTC |
| Source: | https://github.com/jeffeaton/epp |
Parse java array from EPP .xml file
.parse_array(x).parse_array(x)
x |
‘xml_node' object with tag ’array' |
Parse java matrix from EPP .xml file
.parse_matrix(x).parse_matrix(x)
x |
‘xml_node' object with tag ’array' and type '[D' or '[I' |
Return workset with names from EPP .xml file
get_eppxml_workset(pjnz)get_eppxml_workset(pjnz)
x |
‘xml_node' object with tag ’array' |
Prepare site-level ANC prevalence data for EPP random-effects likelihood
prepare_ancsite_likdat(eppd, anchor.year = 1970L)prepare_ancsite_likdat(eppd, anchor.year = 1970L)
eppd |
EPP data object |
anchor.year |
year in which EPP data inputs start NOTE: requires year to be stored in column names of anc.prev |
Reads the HIV prevalence from sentinel surveillance and household surveillance data from the EPP .xml file within a PJNZ.
read_epp_data(pjnz)read_epp_data(pjnz)
pjnz |
file path to Spectrum PJNZ file. |
EPP projection sets are identified in the .xml file by searching the XML tree for tag "object", and then selecting objects with "class" attribute equal to "epp2011.core.sets.ProjectionSet".
Reads the subpopulation configuration and population sizes from the EPP .xml file within a PJNZ.
read_epp_subpops(pjnz)read_epp_subpops(pjnz)
pjnz |
file path to Spectrum PJNZ file. |
EPP projection sets are identified in the .xml file by searching the XML tree for tag "object", and then selecting objects with "class" attribute equal to "epp2011.core.sets.ProjectionSet".
Parse 'Worset option' selections for overall EPP workset in the "Model options" pop up box in the Curve Fitting workflow
read_epp_workset_options(pjnz)read_epp_workset_options(pjnz)
pjnz |
file path to Spectrum PJNZ file |
Read Bayesian Median outputs from XML
read_eppxml_results(pjnz)read_eppxml_results(pjnz)
pjnz |